@@ -5,7 +5,6 @@ import os
 import sys
 import tempfile
 import shutil
-import platform
 
 import pytest
 import cairo
@@ -40,7 +39,6 @@ def cairo_ver():
     return tuple(map(int, cairo.cairo_version_string().split(".")))
 
 
-@pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 @given(path=fspaths())
 @settings(max_examples=500)
 def test_fspaths(tempdir_path, path):
